Learn R Programming

L2DensityGoFtest (version 0.6.0)

cutoff.asymptotic: Asymptoticaly normal critical value for the goodness-of-fit test statistic \(\hat{S}_n(h)\) of Bagkavos, Patil and Wood (2021)

Description

Implements an asymptoticaly normal critical value for testing the goodness-of-fit of a parametrically estimated density with the test statistic S.n.

Usage

cutoff.asymptotic(dist,  p1, p2, sig.lev)

Value

A scalar, the estimate of the asymptotic critical value at the given significance level.

Arguments

dist

The null distribution.

p1

Parameter 1 (vector or object) for the null distribution.

p2

Parameter 2 (vector or object) for the null distribution.

sig.lev

Significance level of the hypothesis test.

Author

Dimitrios Bagkavos

R implementation and documentation: Dimitrios Bagkavos <dimitrios.bagkavos@gmail.com>

Details

Implements the asymptotic critical value defined in Remark 1, Bagkavos, Patil and Wood (2021), equal to \( z_\alpha \sigma_{0, \theta_0} \) where \(z_\alpha\) is the \(1-\alpha\) quantile of the normal distribution and $$ \sigma_{0, \theta_0}^2 = 2 \left (\int K^2(u)\,du \right ) \left (\int f^2_0(x; \theta_0)\,dx \right ). $$

References

Bagkavos, Patil and Wood: Nonparametric goodness-of-fit testing for a continuous multivariate parametric model, (2021), under review.

See Also

cutoff.edgeworth, cutoff.bootstrap