Implements an asymptoticaly normal critical value for testing the goodness-of-fit of a parametrically estimated density with the test statistic S.n.
cutoff.asymptotic(dist, p1, p2, sig.lev)A scalar, the estimate of the asymptotic critical value at the given significance level.
The null distribution.
Parameter 1 (vector or object) for the null distribution.
Parameter 2 (vector or object) for the null distribution.
Significance level of the hypothesis test.
Dimitrios Bagkavos
R implementation and documentation: Dimitrios Bagkavos <dimitrios.bagkavos@gmail.com>
Implements the asymptotic critical value defined in Remark 1, Bagkavos, Patil and Wood (2021), equal to \( z_\alpha \sigma_{0, \theta_0} \) where \(z_\alpha\) is the \(1-\alpha\) quantile of the normal distribution and $$ \sigma_{0, \theta_0}^2 = 2 \left (\int K^2(u)\,du \right ) \left (\int f^2_0(x; \theta_0)\,dx \right ). $$
Bagkavos, Patil and Wood: Nonparametric goodness-of-fit testing for a continuous multivariate parametric model, (2021), under review.
cutoff.edgeworth, cutoff.bootstrap