Implements the critical value for the density goodness-of-fit test S.n, approximating via an Edgeworth expansion the size function of the test statistic S.n.
cutoff.edgeworth(xin, dist, kfun, p1, p2, sig.lev)A scalar, the estimate of the critical value at the given significance level.
A vector of data points - the available sample.
The null distribution.
The kernel to use in the density estimates used in the bandwidth expression.
Parameter 1 (vector or object) for the null distribution.
Parameter 2 (vector or object) for the null distribution.
Significance level of the hypothesis test.
Dimitrios Bagkavos
R implementation and documentation: Dimitrios Bagkavos <dimitrios.bagkavos@gmail.com>
Implements the critical value for the density goodness-of-fit test S.n, approximating via an Edgeworth expansion the size function of the test statistic S.n, given by
$$ l_\alpha = z_\alpha + d_0 \sqrt{h} + d_2(n \sqrt{h})^{-1} $$
where \(z_\alpha\) is the \(1-\alpha\) quantile of the normal distribution and
\(d_0 = d_1 - C_{ H_0}\) and $$d_j = (z_\alpha^2 - 1)c_j, j=1,2$$ with
$$
c_1 = \frac{4K^{(3)}(0)\mu_2^3 \nu_3}{3\sigma^3}, \; c_2 = \frac{\mu_3^2K^2(0)}{\sigma^3}, \; \mu_i =\int K^i(x)\,dx, i=1,\dots.
$$
and
$$
C_{H_0} = 2\left (E f_0'( \theta_0) \right )^2 \Delta^{-1}, \; \nu_i = E \left \{f^{i}(x)\right \} = \int f^{i+1}(x)\,dx, i=1,\dots
$$
This critical value is the density function equivalent to the critical value estimate obtained in the closely relatated regression setting in Gao and Gijbels (2008) and is suitable for finite sample implementations of the test.
Gao and Gijbels, Bandwidth selection in nonparametric kernel testing, pp. 1584-1594, JASA (2008)
cutoff.asymptotic, cutoff.bootstrap